@@ -126,6 +126,10 @@ bool TransformationManager::initializeCompilerInstance(std::string &ErrorMsg)
       LSTD = LangStandard::Kind::lang_cxx2a;
 #else
       LSTD = LangStandard::Kind::lang_cxx20;
+#endif
+#if LLVM_VERSION_MAJOR >= 14
+    else if (!CXXStandard.compare("c++2b"))
+      LSTD = LangStandard::Kind::lang_cxx2b;
 #endif
     else {
       ErrorMsg = "Can't parse CXXStandard option argument!";
@@ -335,6 +339,7 @@ bool TransformationManager::doTransformation(std::string &ErrorMsg, int &ErrorCo
   CurrentTransformationImpl->setWarnOnCounterOutOfBounds(WarnOnCounterOutOfBounds);
   CurrentTransformationImpl->setQueryInstanceFlag(QueryInstanceOnly);
   CurrentTransformationImpl->setTransformationCounter(TransformationCounter);
+  CurrentTransformationImpl->setPreprocessor(&ClangInstance->getPreprocessor());
   if (ToCounter > 0) {
     if (CurrentTransformationImpl->isMultipleRewritesEnabled()) {
       CurrentTransformationImpl->setToCounter(ToCounter);
