@@ -13,7 +13,7 @@ class TestCvise(unittest.TestCase):
         binary = os.path.join(current, '../cvise.py')
         shutil.copy(os.path.join(current, 'sources', testcase), '.')
         os.chmod(testcase, 0o644)
-        cmd = '%s %s %s' % (binary, testcase, arguments)
+        cmd = f'{binary} {testcase} {arguments}'
         subprocess.check_output(cmd, shell=True, encoding='utf8')
         with open(testcase) as f:
             content = f.read()
